@@ -11,7 +11,7 @@ dll_name = None
 if sys.platform == "linux" or sys.platform == "linux2":
     dll_name = 'libwoebin.so'
 elif sys.platform == "darwin":
-    dll_name = 'woebin.dylib'
+    dll_name = 'libwoebin.dylib'
 elif sys.platform == "win32":
     dll_name = 'woebin.dll'
 
